! Plots magnetometer data collected by the Collect.bas
! program. The field strength is in micro Teslas. All
! three axis are shown:
!
! Red    X Axis   Left/right across iPhone screen
! Green  Y Axis   Up/down on the iPhone screen
! Blue   Z Axis   Perpendicular to the iPhone screen
!
! Author: Mike Westerfield
! Date: October 2011
! Written in techBASIC 1.0.2
! This source code is released to the public domain.

! Get the file to plot.
input "File to plot: "; name$

! Find out how many data points there are. While we're
! at it, record the time for the first data point.
count = 0
open name$ for input as #1
while not eof(1)
  get #1,, x
  if count = 11 then t0 = x
  count = count + 1
wend
close #1
count = count/12

! Read the magnetometer data.
!
! Find the min/max x/y for the plot.
dim ax(count, 2), ay(count, 2), az(count, 2)
minx = 1e30
miny = 1e30
maxx = -1e30
maxy = -1e30
open name$ for input as #1
for index = 1 to count
  ! Skip the accelerometer and gyroscope data.
  for dump = 1 to 8
    get #1,, x
  next
  
  ! Read the magnetic field strength.
  get #1,, ax(index, 2)
  get #1,, ay(index, 2)
  get #1,, az(index, 2)

  ! Read the gyroscope time stamp, subtracting the
  ! initial time so it is zero based.
  get #1,, ax(index, 1)
  ax(index, 1) = ax(index, 1) - t0
  ay(index, 1) = ax(index, 1)
  az(index, 1) = ax(index, 1)
  
  ! Adjust the min/max values for the graph.
  if minx > ax(index, 1) then minx = ax(index, 1)
  if maxx < ax(index, 1) then maxx = ax(index, 1)
  if miny > ax(index, 2) then miny = ax(index, 2)
  if miny > ay(index, 2) then miny = ay(index, 2)
  if miny > az(index, 2) then miny = az(index, 2)
  if maxy < ax(index, 2) then maxy = ax(index, 2)
  if maxy < ay(index, 2) then maxy = ay(index, 2)
  if maxy < az(index, 2) then maxy = az(index, 2)
next

! Create the plot.
dim p as Plot
p = graphics.newPlot
p.setTitle("Magnetic Field Strength in micro Teslas")
p.setXAxisLabel("Time in seconds")
p.setYAxisLabel("Field Axis: X: Red, Y: Green, Z: Blue")

! Plot the field strength about the X axis (left & right
! along the iPhone screen).
dim px as PlotPoint
px = p.newPlot(ax)
px.setColor(1, 0, 0)
px.setPointColor(1, 0, 0)
px.setStyle(2)

! Plot the field strength about the Y axis (vertical
! along the iPhone screen).
dim py as PlotPoint
py = p.newPlot(ay)
py.setColor(0, 1, 0)
py.setPointColor(0, 1, 0)
py.setStyle(3)

! Plot the field strength about the Z axis (perpendicular
! to the iPhone screen).
dim pz as PlotPoint
pz = p.newPlot(az)
pz.setColor(0, 0, 1)
pz.setPointColor(0, 0, 1)
pz.setStyle(4)

! Set the plot range and domain. This must be done
! after adding the first PlotPoint, since that also
! sets the range and domain.
p.setView (minx, miny, maxx, maxy, 0)

! Show the plot.
system.showGraphics